@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef GRAVATARRESOLVURLJOBTEST_H
-#define GRAVATARRESOLVURLJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -31,4 +30,3 @@ private Q_SLOTS:
     void shouldUseHttps();
 };
 
-#endif // GRAVATARRESOLVURLJOBTEST_H
