@@ -4,15 +4,13 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef GRAVATARRESOLVURLJOB_H
-#define GRAVATARRESOLVURLJOB_H
+#pragma once
 
 #include "gravatar_export.h"
-#include <QNetworkReply>
 #include <QObject>
 #include <QPixmap>
 #include <QUrl>
-
+class QNetworkReply;
 class GravatarResolvUrlJobTest;
 namespace Gravatar
 {
@@ -68,4 +66,3 @@ private:
 };
 }
 
-#endif // GRAVATARRESOLVURLJOB_H
